local LimitedStockBuyer = select(2,...)
local AceGUI = LibStub("AceGUI-3.0")
local GUI = LimitedStockBuyer
local Util = LimitedStockBuyer

--- Default the Ace3 size
local WIDTH = 400 
local HEIGHT = 300

local TitleWidth = 0.6 --- Width of scroll frame title and the rest
local AmountWidth = 0.2
local PriceWidth = 0.2

GUI.frameOpen = false;  -- Holds whether the main frame is open or closed.

function GUI:HandleFrame() --- Open/close Frame
	if GUI.frameOpen == false then --- if not open
		
		GUI.Mainframe = AceGUI:Create("Frame")
		GUI.Mainframe:SetTitle("Limited Stock Buyer")
		GUI.Mainframe:SetHeight(HEIGHT)
		GUI.Mainframe:SetWidth(WIDTH)
		GUI.Mainframe:EnableResize(false)
		GUI.Mainframe:SetStatusText("LSB v"..LimitedStockBuyer.version)
		GUI.Mainframe:SetCallback("OnClose", function(widget) GUI.frameOpen = false; AceGUI:Release(GUI.Mainframe) end)
		GUI.Mainframe:SetLayout("Flow")

		local scrollcontainer = AceGUI:Create("SimpleGroup")
		scrollcontainer:SetFullWidth(true)
		scrollcontainer:SetHeight((HEIGHT-100))
		scrollcontainer:SetLayout("Fill")

		GUI.Mainframe:AddChild(scrollcontainer)

		GUI.scroll = AceGUI:Create("ScrollFrame")
		GUI.scroll:SetLayout("List") 
		scrollcontainer:AddChild(GUI.scroll)
		
		LimitedStockBuyer:ErrorMessage("Opening")
		GUI.frameOpen = true
		
		local BuyAllButton = AceGUI:Create("Button")
		BuyAllButton:SetText("Buy All")
		BuyAllButton:SetWidth(WIDTH)
		BuyAllButton:SetCallback("OnClick", function(widget) Util:BuyAllItems() end)
		
		GUI.Mainframe:AddChild(BuyAllButton)
		
	elseif GUI.frameOpen == true then -- if open
		LimitedStockBuyer:ErrorMessage("Closing")
		AceGUI:Release(GUI.Mainframe) --- release the KRAKEN(Frame)
		GUI.frameOpen = false
	else --- if unknown
		LimitedStockBuyer:Print("There has been an error with opening or closing the mainframe please contact the author with this information and what you were doing when it happened.")
	end
end


function GUI:CreateFrameItems() --- Creates the limited supply item buttons as interactive labels

		------ TITLE HEADERS -- 
		local TitleFrame = AceGUI:Create("SimpleGroup") --- Item Group
		TitleFrame:SetHeight(100)
		TitleFrame:SetFullWidth()
		TitleFrame:SetLayout("Flow")
		GUI.scroll:AddChild(TitleFrame)

		local TitleItemText = AceGUI:Create("InteractiveLabel") -- item name + Image
		TitleItemText:SetText("Item Name")
		TitleItemText:SetRelativeWidth(TitleWidth)
		TitleItemText:SetFont("DEFAULT", 30, "OUTLINE")
		TitleFrame:AddChild(TitleItemText)

		local TitleItemAmount = AceGUI:Create("InteractiveLabel") -- Item Available
		TitleItemAmount:SetText("Amount")
		TitleItemAmount:SetRelativeWidth(AmountWidth)
		TitleItemAmount:SetFont("DEFAULT", 30, "OUTLINE")
		TitleFrame:AddChild(TitleItemAmount)
		
		local TitleItemPrice = AceGUI:Create("InteractiveLabel") -- Item Price
		TitleItemPrice:SetText("Price")
		TitleItemPrice:SetRelativeWidth(PriceWidth)
		TitleItemPrice:SetFont("DEFAULT", 30, "OUTLINE")
		TitleFrame:AddChild(TitleItemPrice)
		
		--- END TITLE HEADERS----
		
	for i=1, LimitedStockBuyer.ButtonListNum, 1 do
		local function LabelClick() --- Function for clicking on label for buying
			LimitedStockBuyer:Print("Buying "..LimitedStockBuyer.ButtonList[i]["name"]) -- Prints what's being bought
			BuyMerchantItem(LimitedStockBuyer.ButtonList[i]["merchItemNum"], 1) -- Buys the item.
			GUI.ReBuild() -- Rebuilds the GUI
		end
		
		local ItemFrame = AceGUI:Create("SimpleGroup") --- Item Group
		ItemFrame:SetHeight(100)
		ItemFrame:SetFullWidth()
		ItemFrame:SetLayout("Flow")
		GUI.scroll:AddChild(ItemFrame)

		local ItemText = AceGUI:Create("InteractiveLabel") -- item name + Image
		ItemText:SetText(LimitedStockBuyer.ButtonList[i]["name"])
		ItemText:SetImage(LimitedStockBuyer.ButtonList[i]["texture"])
		ItemText:SetRelativeWidth(TitleWidth)
		ItemText:SetFont("DEFAULT", 30, "OUTLINE")
		ItemText:SetCallback("OnClick", function(widget) LabelClick() end)
		ItemFrame:AddChild(ItemText)

		local ItemAmount = AceGUI:Create("InteractiveLabel") -- Item Available
		ItemAmount:SetText(LimitedStockBuyer.ButtonList[i]["numAvailable"])
		ItemAmount:SetRelativeWidth(AmountWidth)
		ItemAmount:SetFont("DEFAULT", 30, "OUTLINE")
		ItemFrame:AddChild(ItemAmount)
		
		local ItemPriceGet = Util:ConvertItemPrice(LimitedStockBuyer.ButtonList[i]["price"])
		local ItemPrice = AceGUI:Create("InteractiveLabel") -- Item Price
		ItemPrice:SetText(ItemPriceGet)
		ItemPrice:SetRelativeWidth(PriceWidth)
		ItemPrice:SetFont("DEFAULT", 30, "OUTLINE")
		ItemFrame:AddChild(ItemPrice)
		
	end
	
end

function GUI.ReBuild() -- Rebuilds the GUI after buying an item or another event requires the items ot be updates
	GUI.Mainframe:DoLayout() -- Recreate mainframe layout
	GUI.scroll:ReleaseChildren() --- Release the scroll children
	GUI.scroll:DoLayout() -- Rebuild the scroll children
	C_Timer.After(0.5, LimitedStockBuyer.GetLimitedStock) -- After 0.5 seconds get new stock. (Allows the vendor time to update with client)
end




